;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;                                                                     ;;;
;;;                     Carnegie Mellon University                      ;;;
;;;                  and Alan W Black and Kevin Lenzo                   ;;;
;;;                      Copyright (c) 1998-2000                        ;;;
;;;                        All Rights Reserved.                         ;;;
;;;                                                                     ;;;
;;; Permission is hereby granted, free of charge, to use and distribute ;;;
;;; this software and its documentation without restriction, including  ;;;
;;; without limitation the rights to use, copy, modify, merge, publish, ;;;
;;; distribute, sublicense, and/or sell copies of this work, and to     ;;;
;;; permit persons to whom this work is furnished to do so, subject to  ;;;
;;; the following conditions:                                           ;;;
;;;  1. The code must retain the above copyright notice, this list of   ;;;
;;;     conditions and the following disclaimer.                        ;;;
;;;  2. Any modifications must be clearly marked as such.               ;;;
;;;  3. Original authors' names are not deleted.                        ;;;
;;;  4. The authors' names are not used to endorse or promote products  ;;;
;;;     derived from this software without specific prior written       ;;;
;;;     permission.                                                     ;;;
;;;                                                                     ;;;
;;; CARNEGIE MELLON UNIVERSITY AND THE CONTRIBUTORS TO THIS WORK        ;;;
;;; DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING     ;;;
;;; ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT  ;;;
;;; SHALL CARNEGIE MELLON UNIVERSITY NOR THE CONTRIBUTORS BE LIABLE     ;;;
;;; FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES   ;;;
;;; WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN  ;;;
;;; AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,         ;;;
;;; ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF      ;;;
;;; THIS SOFTWARE.                                                      ;;;
;;;                                                                     ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; Lexicon, LTS and Postlexical rules for net_dutch
;;;

;;; Load any necessary files here

(define (net_dutch_addenda)
  "(net_dutch_addenda)
Basic lexicon should (must ?) have basic letters, symbols and punctuation."

;;; Pronunciation of the numerical words:
;; !--------------------------------------------------------------
;; every word is accented to make sure the intonation module
;; tries to pronounce them explicitly.. or something... :)
(lex.add.entry '("nul" nn (((n ux l) 1)((#) 0))))
(lex.add.entry '("een" nn (((e: n ) 1)((#) 0))))
(lex.add.entry '("twee" nn (((t V[) 0) (( e: ) 1)((#) 0))))
(lex.add.entry '("drie" nn (((d R i: ) 1)((#) 0))))
(lex.add.entry '("vier" nn (((v i: R ) 1)((#) 0))))
(lex.add.entry '("vijf" nn (((v Ei f ) 1)((#) 0))))
(lex.add.entry '("zes" nn (((z e s ) 1)((#) 0))))
(lex.add.entry '("zeven" nn (((z e:) 1)(( v & n #) 0))))
(lex.add.entry '("acht" nn (((a x t ) 1)((#) 0))))
(lex.add.entry '("negen" nn (((n e:) 1)((G & n #) 0))))
;; !--------------------------------------------------------------

(lex.add.entry '("zegen" nn (((z e:) 1)((G & n #) 0))))
(lex.add.entry '("even" nn (((e:) 1)((v & n #) 0))))
(lex.add.entry '("eveneen" nn (((e:) 1)((v & n) 0)((e: n) 1))))


;; Basic punctuation must be in with nil pronunciation
(lex.add.entry '("." punc nil))
;(lex.add.entry '("." nn (((p u1 n) 1) ((t o) 0))))
(lex.add.entry '("'" punc nil))
(lex.add.entry '(":" punc nil))
(lex.add.entry '(";" punc nil))
(lex.add.entry '("," punc nil))
;(lex.add.entry '("," nn (((k o1) 1) ((m a) 0))))
(lex.add.entry '("-" punc nil))
(lex.add.entry '("\"" punc nil))
(lex.add.entry '("`" punc nil))
(lex.add.entry '("?" punc nil))
(lex.add.entry '("!" punc nil))
)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; Hand written letter to sound rules
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;  Function called when word not found in lexicon
(define (net_dutch_lts_function word features)
  "(net_dutch_lts_function WORD FEATURES)
Return pronunciation of word not in lexicon."
  (format stderr "failed to find pronunciation for %s\n" word)
  (let ((dword (downcase word)))
    ;; Note you may need to use a letter to sound rule set to do
    ;; casing if the language has non-ascii characters in it.
    (if (lts.in.alphabet word 'net_dutch)
	(list
	 word
	 features
	 ;; This syllabification is almost certainly wrong for
	 ;; this language (its not even very good for English)
	 ;; but it will give you something to start off with
	 (lex.syllabify.phstress
	   (lts.apply word 'net_dutch)))
	(begin
	  (format stderr "unpronouncable word %s\n" word)
	  ;; Put in a word that means "unknown" with its pronunciation
	  '("nie" nil (((n i: #) 0 ))))))
)

;; You may or may not be able to write a letter to sound rule set for
;; your language.  If its largely lexicon based learning a rule
;; set will be better and easier that writing one (probably).
(lts.ruleset
 net_dutch
 (  (Vowel WHATEVER) )
 (
  ;; LTS rules 
  ))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; Postlexical Rules 
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define (net_dutch::postlex_rule1 utt)
  "(net_dutch::postlex_rule1 utt)
A postlexical rule form correcting phenomena over word boundaries."
  (mapcar
   (lambda (s)
     ;; do something
     )
   (utt.relation.items utt 'Segment))
   utt)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; Lexicon definition
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(lex.create "net_dutch")
(lex.set.phoneset "net_dutch")
(lex.set.lts.method 'net_dutch_lts_function)
;;; If you have a compiled lexicon uncomment this
;(lex.set.compile.file (path-append net_dutch_frans_dir "festvox/net_dutch_lex.out"))
(net_dutch_addenda)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; Lexicon setup
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define (net_dutch_frans::select_lexicon)
  "(net_dutch_frans::select_lexicon)
Set up the lexicon for net_dutch."
  (lex.select "net_dutch")

  ;; Post lexical rules
  (set! postlex_rules_hooks (list net_dutch::postlex_rule1))
)

(define (net_dutch_frans::reset_lexicon)
  "(net_dutch_frans::reset_lexicon)
Reset lexicon information."
  t
)

(provide 'net_dutch_frans_lexicon)
