;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;                                                                     ;;;
;;;                     Carnegie Mellon University                      ;;;
;;;                  and Alan W Black and Kevin Lenzo                   ;;;
;;;                      Copyright (c) 1998-2000                        ;;;
;;;                        All Rights Reserved.                         ;;;
;;;                                                                     ;;;
;;; Permission is hereby granted, free of charge, to use and distribute ;;;
;;; this software and its documentation without restriction, including  ;;;
;;; without limitation the rights to use, copy, modify, merge, publish, ;;;
;;; distribute, sublicense, and/or sell copies of this work, and to     ;;;
;;; permit persons to whom this work is furnished to do so, subject to  ;;;
;;; the following conditions:                                           ;;;
;;;  1. The code must retain the above copyright notice, this list of   ;;;
;;;     conditions and the following disclaimer.                        ;;;
;;;  2. Any modifications must be clearly marked as such.               ;;;
;;;  3. Original authors' names are not deleted.                        ;;;
;;;  4. The authors' names are not used to endorse or promote products  ;;;
;;;     derived from this software without specific prior written       ;;;
;;;     permission.                                                     ;;;
;;;                                                                     ;;;
;;; CARNEGIE MELLON UNIVERSITY AND THE CONTRIBUTORS TO THIS WORK        ;;;
;;; DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING     ;;;
;;; ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT  ;;;
;;; SHALL CARNEGIE MELLON UNIVERSITY NOR THE CONTRIBUTORS BE LIABLE     ;;;
;;; FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES   ;;;
;;; WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN  ;;;
;;; AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,         ;;;
;;; ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF      ;;;
;;; THIS SOFTWARE.                                                      ;;;
;;;                                                                     ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; Tokenizer for dutch
;;;
;;;  To share this among voices you need to promote this file to
;;;  to say festival/lib/net_dutch/ so others can use it.
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;; Load any other required files

;;; Voice/dutch token_to_word rules 
(define (net_dutch_frans::token_to_words token name)
  "(net_dutch_frans::token_to_words token name)
Specific token to word rules for the voice net_dutch_frans.  Returns a list
of words that expand given token with name."
  (cond
   ((string-matches name "[0-9]+")
    (net_dutch::number token name))
   (t ;; when no specific rules apply do the general ones
    (list name))))

(set! net_dutch::digit_names
    '((0 "nul")
      (1 "een")
      (2 "twee")
      (3 "drie")
      (4 "vier")
      (5 "vijf")
      (6 "zes")
      (7 "zeven")
      (8 "acht")
      (9 "negen")))

(define (net_dutch::number token name)
  "(net_dutch::number token name)
Return list of words that pronounce this number in dutch."
  (mapcar (lambda (d)
    (car (cdr (assoc_string d net_dutch::digit_names))))
      (symbolexplode name))
)

(define (net_dutch_frans::select_tokenizer)
  "(net_dutch_frans::select_tokenizer)
Set up tokenizer for dutch."
  (Parameter.set 'Language 'net_dutch)

  (set! token_to_words net_dutch_frans::token_to_words)
)

(define (net_dutch_frans::reset_tokenizer)
  "(net_dutch_frans::reset_tokenizer)
Reset any globals modified for this voice.  Called by 
(net_dutch_frans::voice_reset)."
  ;; None

  t
)

(provide 'net_dutch_frans_tokenizer)
